==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetActionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionId Action ID
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property ruleId Alert rule ID
 * @property workspaceName The name of the workspace.
 */
public data class GetActionPlainArgs(
    public val actionId: String,
    public val resourceGroupName: String,
    public val ruleId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs.builder()
            .actionId(actionId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleId(ruleId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetActionPlainArgs].
 */
@PulumiTagMarker
public class GetActionPlainArgsBuilder internal constructor() {
    private var actionId: String? = null

    private var resourceGroupName: String? = null

    private var ruleId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Action ID
     */
    @JvmName("emmwiojgvdsaysln")
    public suspend fun actionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("fasrswnpjyianmcf")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Alert rule ID
     */
    @JvmName("ijsklrtxxvqqxbnr")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("xtbtjjulfrlbmkbf")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetActionPlainArgs = GetActionPlainArgs(
        actionId = actionId ?: throw PulumiNullFieldException("actionId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetActionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionId Action ID
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property ruleId Alert rule ID
 * @property workspaceName The name of the workspace.
 */
public data class GetActionPlainArgs(
    public val actionId: String,
    public val resourceGroupName: String,
    public val ruleId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetActionPlainArgs.builder()
            .actionId(actionId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleId(ruleId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetActionPlainArgs].
 */
@PulumiTagMarker
public class GetActionPlainArgsBuilder internal constructor() {
    private var actionId: String? = null

    private var resourceGroupName: String? = null

    private var ruleId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Action ID
     */
    @JvmName("jnmufjsylaqwfetd")
    public suspend fun actionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("lhhdsjetvnuljvlb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Alert rule ID
     */
    @JvmName("hnwqjigldefboeis")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("iawdiqlhnifjmver")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetActionPlainArgs = GetActionPlainArgs(
        actionId = actionId ?: throw PulumiNullFieldException("actionId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
